==> gandalf_1.3.2.orig.tar.gz: gandalf/image.h <==
#include <gandalf/image/image_bit.h>
#include <gandalf/image/image_channel.h>
#include <gandalf/image/image_compare.h>
#include <gandalf/image/image_composite.h>
#include <gandalf/image/image_defs.h>
#include <gandalf/image/image_display.h>
#include <gandalf/image/image_extract.h>
#include <gandalf/image/image_flip.h>
#include <gandalf/image/image_gla_double.h>
#include <gandalf/image/image_gla_float.h>
#include <gandalf/image/image_gla_int.h>
#include <gandalf/image/image_gla_short.h>
#include <gandalf/image/image_gla_uchar.h>
#include <gandalf/image/image_gla_uint16.h>
#include <gandalf/image/image_gla_uint32.h>
#include <gandalf/image/image_gla_uint8.h>
#include <gandalf/image/image_gla_uint.h>
#include <gandalf/image/image_gla_ushort.h>
#include <gandalf/image/image_gl_double.h>
#include <gandalf/image/image_gl_float.h>
#include <gandalf/image/image_gl_int.h>
#include <gandalf/image/image_gl_short.h>
#include <gandalf/image/image_gl_uchar.h>
#include <gandalf/image/image_gl_uint16.h>
#include <gandalf/image/image_gl_uint32.h>
#include <gandalf/image/image_gl_uint8.h>
#include <gandalf/image/image_gl_uint.h>
#include <gandalf/image/image_gl_ushort.h>
#include <gandalf/image/image_invert.h>
#include <gandalf/image/image_pointer.h>
#include <gandalf/image/image_pyramid.h>
#include <gandalf/image/image_rgba_double.h>
#include <gandalf/image/image_rgba_float.h>
#include <gandalf/image/image_rgba_int.h>
#include <gandalf/image/image_rgba_short.h>
#include <gandalf/image/image_rgba_uchar.h>
#include <gandalf/image/image_rgba_uint16.h>
#include <gandalf/image/image_rgba_uint32.h>
#include <gandalf/image/image_rgba_uint8.h>
#include <gandalf/image/image_rgba_uint.h>
#include <gandalf/image/image_rgba_ushort.h>
#include <gandalf/image/image_rgb_double.h>
#include <gandalf/image/image_rgb_float.h>
#include <gandalf/image/image_rgb_int.h>
#include <gandalf/image/image_rgb_short.h>
#include <gandalf/image/image_rgb_uchar.h>
#include <gandalf/image/image_rgb_uint16.h>
#include <gandalf/image/image_rgb_uint32.h>
#include <gandalf/image/image_rgb_uint8.h>
#include <gandalf/image/image_rgb_uint.h>
#include <gandalf/image/image_rgb_ushort.h>
#include <gandalf/image/image_vfield2D_double.h>
#include <gandalf/image/image_vfield2D_float.h>
#include <gandalf/image/image_vfield2D_int.h>
#include <gandalf/image/image_vfield2D_short.h>
#include <gandalf/image/image_vfield3D_double.h>
#include <gandalf/image/image_vfield3D_float.h>
#include <gandalf/image/image_vfield3D_int.h>
#include <gandalf/image/image_vfield3D_short.h>
#include <gandalf/image/io.h>
#include <gandalf/image/pixel.h>

==> gandalf_1.5.orig.tar.gz: gandalf/image.h <==
#include <gandalf/image/image_bit.h>
#include <gandalf/image/image_channel.h>
#include <gandalf/image/image_compare.h>
#include <gandalf/image/image_composite.h>
#include <gandalf/image/image_defs.h>
#include <gandalf/image/image_display.h>
#include <gandalf/image/image_extract.h>
#include <gandalf/image/image_flip.h>
#include <gandalf/image/image_gla_double.h>
#include <gandalf/image/image_gla_float32.h>
#include <gandalf/image/image_gla_float.h>
#include <gandalf/image/image_gla_int.h>
#include <gandalf/image/image_gla_short.h>
#include <gandalf/image/image_gla_uchar.h>
#include <gandalf/image/image_gla_uint16.h>
#include <gandalf/image/image_gla_uint32.h>
#include <gandalf/image/image_gla_uint8.h>
#include <gandalf/image/image_gla_uint.h>
#include <gandalf/image/image_gla_ushort.h>
#include <gandalf/image/image_gl_double.h>
#include <gandalf/image/image_gl_float32.h>
#include <gandalf/image/image_gl_float.h>
#include <gandalf/image/image_gl_int.h>
#include <gandalf/image/image_gl_short.h>
#include <gandalf/image/image_gl_uchar.h>
#include <gandalf/image/image_gl_uint16.h>
#include <gandalf/image/image_gl_uint32.h>
#include <gandalf/image/image_gl_uint8.h>
#include <gandalf/image/image_gl_uint.h>
#include <gandalf/image/image_gl_ushort.h>
#include <gandalf/image/image_invert.h>
#include <gandalf/image/image_pointer.h>
#include <gandalf/image/image_pyramid.h>
#include <gandalf/image/image_rgba_double.h>
#include <gandalf/image/image_rgba_float32.h>
#include <gandalf/image/image_rgba_float.h>
#include <gandalf/image/image_rgba_int.h>
#include <gandalf/image/image_rgba_short.h>
#include <gandalf/image/image_rgba_uchar.h>
#include <gandalf/image/image_rgba_uint16.h>
#include <gandalf/image/image_rgba_uint32.h>
#include <gandalf/image/image_rgba_uint8.h>
#include <gandalf/image/image_rgba_uint.h>
#include <gandalf/image/image_rgba_ushort.h>
#include <gandalf/image/image_rgb_double.h>
#include <gandalf/image/image_rgb_float32.h>
#include <gandalf/image/image_rgb_float.h>
#include <gandalf/image/image_rgb_int.h>
#include <gandalf/image/image_rgb_short.h>
#include <gandalf/image/image_rgb_uchar.h>
#include <gandalf/image/image_rgb_uint16.h>
#include <gandalf/image/image_rgb_uint32.h>
#include <gandalf/image/image_rgb_uint8.h>
#include <gandalf/image/image_rgb_uint.h>
#include <gandalf/image/image_rgb_ushort.h>
#include <gandalf/image/image_scale.h>
#include <gandalf/image/image_vfield2D_double.h>
#include <gandalf/image/image_vfield2D_float32.h>
#include <gandalf/image/image_vfield2D_float64.h>
#include <gandalf/image/image_vfield2D_float.h>
#include <gandalf/image/image_vfield2D_int16.h>
#include <gandalf/image/image_vfield2D_int32.h>
#include <gandalf/image/image_vfield2D_int.h>
#include <gandalf/image/image_vfield2D_short.h>
#include <gandalf/image/image_vfield3D_double.h>
#include <gandalf/image/image_vfield3D_float32.h>
#include <gandalf/image/image_vfield3D_float64.h>
#include <gandalf/image/image_vfield3D_float.h>
#include <gandalf/image/image_vfield3D_int16.h>
#include <gandalf/image/image_vfield3D_int32.h>
#include <gandalf/image/image_vfield3D_int.h>
#include <gandalf/image/image_vfield3D_short.h>
#include <gandalf/image/io.h>
#include <gandalf/image/pixel.h>
